usr/src/uts/common/fs/zfs/dmu_send.c
changeset 8644 10534c530688
parent 7994 7a573dc88b73
child 8986 45c289aff7c9
--- a/usr/src/uts/common/fs/zfs/dmu_send.c	Wed Jan 28 12:09:40 2009 -0800
+++ b/usr/src/uts/common/fs/zfs/dmu_send.c	Wed Jan 28 15:32:27 2009 -0700
@@ -19,7 +19,7 @@
  * CDDL HEADER END
  */
 /*
- * Copyright 2008 Sun Microsystems, Inc.  All rights reserved.
+ * Copyright 2009 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
@@ -816,10 +816,11 @@
 		/* currently allocated, want to be allocated */
 		dmu_tx_hold_bonus(tx, drro->drr_object);
 		/*
 		 * We may change blocksize, so need to
 		 * hold_write
 		 */
 		dmu_tx_hold_write(tx, drro->drr_object, 0, 1);
+		dmu_tx_hold_free(tx, drro->drr_object, 0, DMU_OBJECT_END);
 		err = dmu_tx_assign(tx, TXG_WAIT);
 		if (err) {
 			dmu_tx_abort(tx);
@@ -816,10 +816,11 @@
 		dmu_tx_hold_bonus(tx, drro->drr_object);
 		/*
-		 * We may change blocksize, so need to
-		 * hold_write
+		 * We may change blocksize and delete old content,
+		 * so need to hold_write and hold_free.
 		 */
 		dmu_tx_hold_write(tx, drro->drr_object, 0, 1);